Image
==========

Image represents abstract API for image managers. It is now implemented by :class:`conu.DockerImage`

.. autoclass:: conu.apidefs.image.Image
   :members:

Image represents abstract API for s2i images. It is now implemented by :class:`conu.S2IDockerImage`

.. autoclass:: conu.apidefs.image.S2Image
   :members:
